@@ -3,8 +3,11 @@ from .cch_dialog import CchDialog
 
 class Dashboard(CchDialog):
 	def __init__(self, app):
-		super(Dashboard, self).__init__(app, 'Dashboard')
-
+		super(Dashboard, self).__init__(
+			app,
+			title='Dashboard',
+			visible_only=False
+		)
 	def select_application_link(self, name):
 		self.window.set_focus()
 		self.window.child_window(
