@@ -1,5 +1,6 @@
 from .cch_dialog import CchDialog
 from ta_cch_axcess import logger
+from pywinauto.timings import TimeoutError as pywinautoTimeoutError
 
 
 class Documents(CchDialog):
@@ -44,12 +45,15 @@ class Documents(CchDialog):
 			auto_id="txtClientFilter", class_name='TextBox'
 		).type_keys('{DOWN}{ENTER}')
 
-		self.window.child_window(
-			auto_id="cmbRecordsPerPage"
-		).wait('ready', timeout=15)
-		self.window.child_window(
-			auto_id="cmbRecordsPerPage"
-		).select("2000")
+		try:
+			self.window.child_window(
+				auto_id="cmbRecordsPerPage"
+			).wait('ready', timeout=15)
+			self.window.child_window(
+				auto_id="cmbRecordsPerPage"
+			).select("2000")
+		except pywinautoTimeoutError as e:
+			logger.warning(f'{e} - No option to change display in file list presented')
 
 		self.window.child_window(
 			title="Incoming files", class_name='TabItem'
@@ -92,7 +96,7 @@ class Documents(CchDialog):
 							if 'Records' in datagrid.legacy_properties()['Name']:
 								list_data = datagrid.children(
 									class_name='Record')
-								cell_to_click = list_data[0].children(
+								cell_to_click = list_data[int(files_number)-1].children(
 									class_name='Cell')
 
 		self.window.child_window(
